@@ -14,7 +14,8 @@ use rustls::ServerConfig;
 use serde::{Deserialize, Serialize};
 use serde_json::json;
 
-use pact_matching::models::{Pact, RequestResponsePact, write_pact, Request};
+use pact_matching::models::{Pact, RequestResponsePact, write_pact};
+use pact_models::request::Request;
 
 use crate::hyper_server;
 use crate::matching::MatchResult;
